## v0.4.0 (2025-11-24)

### Feat

- config service agnostic from environment

### Refactor

- amend pipeline to publish to feed

## v0.3.1 (2025-11-03)

### Fix

- ammend update of cz version

## v0.3.0 (2025-11-03)

## v0.2.1 (2025-10-30)

### Feat

- load group of vars

### Fix

- try other approach to set pypi-token
- see pypi token

## v0.2.0 (2025-10-30)

### Feat

- first relase is raised

### Fix

- correct bumping
